@@ -3,7 +3,7 @@ BEGIN {
   $SyForm::Process::AUTHORITY = 'cpan:GETTY';
 }
 # ABSTRACT: Role for processed fields
-$SyForm::Process::VERSION = '0.008';
+$SyForm::Process::VERSION = '0.009';
 use Moose::Role;
 use Moose::Meta::Class;
 use Moose::Meta::Attribute;
@@ -26,17 +26,18 @@ sub _build_values_object_class { $_[0]->object_class }
 has values_roles => (
   isa => 'ArrayRef[Str]',
   is => 'ro',
-  lazy => 1,
-  default => sub {[]},
+  lazy_build => 1,
 );
 
-has _values_metaclass => (
+sub _build_values_roles {[]}
+
+has values_metaclass => (
   isa => 'Moose::Meta::Class',
   is => 'ro',
   lazy_build => 1,
 );
 
-sub _build__values_metaclass {
+sub _build_values_metaclass {
   my ( $self ) = @_;
   return Moose::Meta::Class->create(
     (ref $self).'::Values',
@@ -53,7 +54,7 @@ has values_class => (
 
 sub _build_values_class {
   my ( $self ) = @_;
-  return $self->_values_metaclass->name;
+  return $self->values_metaclass->name;
 }
 
 ##########
@@ -94,7 +95,7 @@ sub process_values {
   my $values;
   eval {
     my %values_args;
-    my @values_traits;
+    my @values_traits = @{$self->values_roles};
     for my $field (@{$self->process_fields}) {
       my %field_values_args = $field->values_args_by_process_args(%args);
       push @values_traits, @{delete $field_values_args{roles}}
@@ -122,7 +123,7 @@ sub create_values {
   }
   return $self->values_class->new_with_traits({
     syform => $self,
-    traits => [ @traits ],
+    scalar @traits ? ( traits => [@traits] ) : (),
     values => { %values },
     %args,
   });
@@ -134,6 +135,14 @@ sub create_values {
 #
 ##################
 
+has results_roles => (
+  isa => 'ArrayRef[Str]',
+  is => 'ro',
+  lazy_build => 1,
+);
+
+sub _build_results_roles {[]}
+
 sub process_results {
   my ( $self, %args ) = @_;
   my $results;
@@ -148,6 +157,14 @@ sub process_results {
 #
 ###############
 
+has view_roles => (
+  isa => 'ArrayRef[Str]',
+  is => 'ro',
+  lazy_build => 1,
+);
+
+sub _build_view_roles {[]}
+
 sub process_view {
   my ( $self, %args ) = @_;
   my $view;
@@ -167,7 +184,7 @@ SyForm::Process - Role for processed fields
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 AUTHOR
 
