@@ -3,9 +3,9 @@ BEGIN {
   $SyForm::View::Verify::AUTHORITY = 'cpan:GETTY';
 }
 # ABSTRACT: Trait for SyForm fields of SyForm::Results and SyForm::Values attributes
-$SyForm::View::Verify::VERSION = '0.008';
+$SyForm::View::Verify::VERSION = '0.009';
 use Moose::Role;
-use namespace::clean;
+use namespace::clean -except => 'meta';
 
 has error_count => (
   is => 'ro',
@@ -30,7 +30,7 @@ SyForm::View::Verify - Trait for SyForm fields of SyForm::Results and SyForm::Va
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 AUTHOR
 
